'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function () {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var files = _ref.files;
    var configFile = _ref.configFile;
    var _ref$fontName = _ref.fontName;
    var fontName = _ref$fontName === undefined ? 'webfont' : _ref$fontName;
    var _ref$formats = _ref.formats;
    var formats = _ref$formats === undefined ? ['svg', 'ttf', 'eot', 'woff', 'woff2'] : _ref$formats;
    var _ref$css = _ref.css;
    var css = _ref$css === undefined ? false : _ref$css;
    var _ref$cssFormat = _ref.cssFormat;
    var cssFormat = _ref$cssFormat === undefined ? 'css' : _ref$cssFormat;
    var _ref$cssTemplateClass = _ref.cssTemplateClassName;
    var cssTemplateClassName = _ref$cssTemplateClass === undefined ? null : _ref$cssTemplateClass;
    var _ref$cssTemplateFontP = _ref.cssTemplateFontPath;
    var cssTemplateFontPath = _ref$cssTemplateFontP === undefined ? './' : _ref$cssTemplateFontP;
    var _ref$cssTemplateFontN = _ref.cssTemplateFontName;
    var cssTemplateFontName = _ref$cssTemplateFontN === undefined ? null : _ref$cssTemplateFontN;
    var _ref$srcCssTemplate = _ref.srcCssTemplate;
    var srcCssTemplate = _ref$srcCssTemplate === undefined ? null : _ref$srcCssTemplate;
    var _ref$formatsOptions = _ref.formatsOptions;
    var formatsOptions = _ref$formatsOptions === undefined ? {
        ttf: {
            copyright: null,
            ts: Math.round(Date.now() / 1000)
        }
    } : _ref$formatsOptions;
    var _ref$metadataProvider = _ref.metadataProvider;
    var metadataProvider = _ref$metadataProvider === undefined ? null : _ref$metadataProvider;
    var _ref$fontId = _ref.fontId;
    var fontId = _ref$fontId === undefined ? null : _ref$fontId;
    var _ref$fontStyle = _ref.fontStyle;
    var fontStyle = _ref$fontStyle === undefined ? '' : _ref$fontStyle;
    var _ref$fontWeight = _ref.fontWeight;
    var fontWeight = _ref$fontWeight === undefined ? '' : _ref$fontWeight;
    var _ref$fixedWidth = _ref.fixedWidth;
    var fixedWidth = _ref$fixedWidth === undefined ? false : _ref$fixedWidth;
    var _ref$centerHorizontal = _ref.centerHorizontally;
    var centerHorizontally = _ref$centerHorizontal === undefined ? false : _ref$centerHorizontal;
    var _ref$normalize = _ref.normalize;
    var normalize = _ref$normalize === undefined ? false : _ref$normalize;
    var _ref$fontHeight = _ref.fontHeight;
    var fontHeight = _ref$fontHeight === undefined ? null : _ref$fontHeight;
    var _ref$round = _ref.round;
    var round = _ref$round === undefined ? 10e12 : _ref$round;
    var _ref$descent = _ref.descent;
    var descent = _ref$descent === undefined ? 0 : _ref$descent;
    var _ref$ascent = _ref.ascent;
    var ascent = _ref$ascent === undefined ? undefined : _ref$ascent;
    var _ref$startUnicode = _ref.startUnicode;
    var startUnicode = _ref$startUnicode === undefined ? 0xEA01 : _ref$startUnicode;
    var _ref$prependUnicode = _ref.prependUnicode;
    var prependUnicode = _ref$prependUnicode === undefined ? false : _ref$prependUnicode;
    var _ref$metadata = _ref.metadata;
    var metadata = _ref$metadata === undefined ? null : _ref$metadata;
    var _ref$quite = _ref.quite;
    var quite = _ref$quite === undefined ? false : _ref$quite;

    if (!files) {
        return Promise.reject(new Error('You must pass webfont a `files` glob'));
    }

    var glyphs = [];

    return buildConfig({
        configFile: configFile
    }).then(function (buildedConfig) {
        var options = (0, _mergeDeep2.default)({}, {
            ascent: ascent,
            centerHorizontally: centerHorizontally,
            css: css,
            cssFormat: cssFormat,
            cssTemplateClassName: cssTemplateClassName,
            cssTemplateFontName: cssTemplateFontName,
            cssTemplateFontPath: cssTemplateFontPath,
            descent: descent,
            fixedWidth: fixedWidth,
            fontHeight: fontHeight,
            fontId: !fontId ? fontName : fontId,
            fontName: fontName,
            fontStyle: fontStyle,
            fontWeight: fontWeight,
            formats: formats,
            formatsOptions: formatsOptions,
            log: quite ? function () {} : console.log, // eslint-disable-line no-console, no-empty-function
            metadata: metadata,
            metadataProvider: metadataProvider,
            normalize: normalize,
            prependUnicode: prependUnicode,
            round: round,
            srcCssTemplate: srcCssTemplate,
            startUnicode: startUnicode
        }, buildedConfig.config);

        return (0, _globby2.default)([].concat(files)).then(function (foundFiles) {
            var filteredFiles = foundFiles.filter(function (foundFile) {
                return _path2.default.extname(foundFile) === '.svg';
            });

            if (filteredFiles.length === 0) {
                return Promise.reject(new Error('Files glob patterns specified did not match any files'));
            }

            return Promise.resolve(filteredFiles);
        }).then(function (foundFiles) {
            return svgIcons2svgFontFn(foundFiles, options, glyphs);
        }).then(function (result) {
            return svg2ttfFn(result, options.formatsOptions.ttf);
        })
        // maybe add ttfautohint
        .then(function (result) {
            if (options.formats.indexOf('eot') === -1) {
                return Promise.resolve(result);
            }

            return ttf2eotFn(result);
        }).then(function (result) {
            if (options.formats.indexOf('woff') === -1) {
                return Promise.resolve(result);
            }

            return ttf2woffFn(result, {
                metadata: metadata
            });
        }).then(function (result) {
            if (options.formats.indexOf('woff2') === -1) {
                return Promise.resolve(result);
            }

            return ttf2woff2Fn(result);
        }).then(function (result) {
            if (!options.css) {
                return Promise.resolve(result);
            }

            if (!options.srcCssTemplate) {
                _nunjucks2.default.configure(_path2.default.join(__dirname, '../'));

                options.srcCssTemplate = _path2.default.join(__dirname, '../templates/template.' + options.cssFormat + '.njk');
            }

            var nunjucksOptions = (0, _mergeDeep2.default)({}, {
                glyphs: glyphs
            }, options, {
                className: options.cssTemplateClassName ? options.cssTemplateClassName : options.fontName,
                fontName: options.cssTemplateFontName ? options.cssTemplateFontName : options.fontName,
                fontPath: options.cssTemplateFontPath
            });

            result.css = _nunjucks2.default.render(_path2.default.resolve(options.srcCssTemplate), nunjucksOptions);

            return result;
        }).then(function (result) {
            if (options.formats.indexOf('svg') === -1) {
                delete result.svg;
            }

            if (options.formats.indexOf('ttf') === -1) {
                delete result.ttf;
            }

            result.config = options;

            return Promise.resolve(result);
        });
    }).catch(function (error) {
        throw error;
    });
};

var _cosmiconfig = require('cosmiconfig');

var _cosmiconfig2 = _interopRequireDefault(_cosmiconfig);

var _metadata = require('svgicons2svgfont/src/metadata');

var _metadata2 = _interopRequireDefault(_metadata);

var _filesorter = require('svgicons2svgfont/src/filesorter');

var _filesorter2 = _interopRequireDefault(_filesorter);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _globby = require('globby');

var _globby2 = _interopRequireDefault(_globby);

var _mergeDeep = require('merge-deep');

var _mergeDeep2 = _interopRequireDefault(_mergeDeep);

var _nunjucks = require('nunjucks');

var _nunjucks2 = _interopRequireDefault(_nunjucks);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _svg2ttf = require('svg2ttf');

var _svg2ttf2 = _interopRequireDefault(_svg2ttf);

var _svgicons2svgfont = require('svgicons2svgfont');

var _svgicons2svgfont2 = _interopRequireDefault(_svgicons2svgfont);

var _ttf2eot = require('ttf2eot');

var _ttf2eot2 = _interopRequireDefault(_ttf2eot);

var _ttf2woff = require('ttf2woff');

var _ttf2woff2 = _interopRequireDefault(_ttf2woff);

var _ttf2woff3 = require('ttf2woff2');

var _ttf2woff4 = _interopRequireDefault(_ttf2woff3);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function svgIcons2svgFontFn(files, options) {
    var glyphs = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

    var fontStream = (0, _svgicons2svgfont2.default)({
        ascent: options.ascent,
        centerHorizontally: options.centerHorizontally,
        descent: options.descent,
        fixedWidth: options.fixedWidth,
        fontHeight: options.fontHeight,
        fontId: options.fontId,
        fontName: options.fontName,
        fontStyle: options.fontStyle,
        fontWeight: options.fontWeight,
        log: options.log,
        metadata: options.metadata,
        normalize: options.normalize,
        round: options.round
    });
    var metadataProvider = options.metadataProvider || (0, _metadata2.default)({
        prependUnicode: options.prependUnicode,
        startUnicode: options.startUnicode
    });

    var sortedFiles = files.sort(function (fileA, fileB) {
        return (0, _filesorter2.default)(fileA, fileB);
    });

    var result = {
        svg: ''
    };

    return Promise.all(sortedFiles.map(function (srcPath) {
        return new Promise(function (resolve, reject) {
            metadataProvider(srcPath, function (error, metadata) {
                if (error) {
                    return reject(new Error(error));
                }

                var glyph = _fs2.default.createReadStream(srcPath);

                glyph.metadata = metadata;
                fontStream.write(glyph);

                glyphs.push(metadata);

                return resolve(glyph);
            });
        });
    })).then(function () {
        fontStream.end();

        return new Promise(function (resolve, reject) {
            fontStream.on('error', function (error) {
                return reject(new Error(error));
            }).on('data', function (data) {
                result.svg += data;
            }).on('end', function () {
                return resolve(result);
            });
        });
    });
}

function svg2ttfFn(result, options) {
    return new Promise(function (resolve) {
        // eslint-disable-next-line node/no-deprecated-api
        result.ttf = new Buffer((0, _svg2ttf2.default)(result.svg.toString(), {
            copyright: options.copyright,
            ts: options.ts,
            version: options.version
        }).buffer);

        return resolve(result);
    });
}

function ttf2eotFn(result) {
    return new Promise(function (resolve) {
        // eslint-disable-next-line node/no-deprecated-api
        result.eot = new Buffer((0, _ttf2eot2.default)(new Uint8Array(result.ttf)).buffer);

        return resolve(result);
    });
}

function ttf2woffFn(result, options) {
    return new Promise(function (resolve) {
        // eslint-disable-next-line node/no-deprecated-api
        result.woff = new Buffer((0, _ttf2woff2.default)(new Uint8Array(result.ttf), options).buffer);

        return resolve(result);
    });
}

function ttf2woff2Fn(result) {
    return new Promise(function (resolve) {
        result.woff2 = (0, _ttf2woff4.default)(result.ttf);

        return resolve(result);
    });
}

function buildConfig(options) {
    if (!options.configFile) {
        return Promise.resolve({});
    }

    var cosmiconfigOptions = {
        // Allow extensions on rc filenames
        rcExtensions: true
    };

    var configPath = process.cwd();

    if (options.configFile) {
        configPath = _path2.default.resolve(process.cwd(), options.configFile);
    }

    return (0, _cosmiconfig2.default)('webfont', cosmiconfigOptions).load(null, configPath).then(function (result) {
        if (!result) {
            return Promise.reject(new Error('No configuration found'));
        }

        return Promise.resolve({
            config: result.config
        });
    });
}